BoltonCms::Display.helpers do

  def render_site_sections(sections, page=nil)
    content_tag :nav, render_page_links(sections, page), class: 'site-sections'
  end

  def render_children(page)
    content_tag :nav, render_page_links(page.children, page), class: 'children'
  end

  def render_page_links(items, page=nil)
    output = ''
    items.each do |item|
      content = page && page.path == item.path ?
        content_tag(:strong, item.title)
      :
        link_to(item.title, item.position == 0 && !item.parent? ? '/' : item.path)

      output << content_tag(:li, content)
    end

    content_tag :ul, output.html_safe
  end

  def render_breadcrumbs(page)
    title = page.title

    output = ''

    while page.has_parent?
      page = page.parent
      output << content_tag(:li, link_to(page.title, page.path))
    end

    output << content_tag(:li, content_tag(:strong, title))

    content_tag :nav, content_tag(:ul, output.html_safe), class: 'breadcrumbs'
  end

  def render_active_fragments(page, wrapper_entity=:section)
    output = ''

    page.active_fragments.each do |label|
      if fragment = @page.find_fragment(label)
        output << content_tag(
          wrapper_entity,
          content_tag('h1', label) << render_cms_content(fragment.filter, fragment.body),
          class: "fragment-#{fragment.label.to_slug.normalize.to_s}"
        )
      end
    end

    output.html_safe
  end

  def render_cms_content(filter, content)
    output = case filter
    when :raw
      content
    else
      BoltonCms::MDR.render(content)
    end

    output.html_safe
  end

end
