BoltonCms::Manage.controllers :accounts do

  before :edit, :update do
    redirect url(:base, :index) if current_account.role != 'admin' && current_account.id.to_s != params[:id]
  end

  get :index do
    @title = 'All Accounts'
    @accounts = Account.all
    render 'accounts/index'
  end

  get :new do
    @title = 'New Accout'
    @account = Account.new
    render 'accounts/new'
  end

  post :create do
    @account = Account.new(params[:account])
    if @account.save
      flash[:success] = "Account #{@account.name} (#{@account.email}) created"
      params[:save_and_continue] ? redirect(url(:accounts, :index)) : redirect(url(:accounts, :edit, id: @account.id))
    else
      flash.now[:error] = "Account #{@account.name} (#{@account.email}) could not be created"
      render 'accounts/new'
    end
  end

  get :edit, with: :id do
    @title = 'Edit Account'
    @account = Account.find(params[:id])
    if @account
      render 'accounts/edit'
    else
      flash[:warning] = "Account could not be found"
      halt 404
    end
  end

  put :update, with: :id do
    @account = Account.find(params[:id])
    if @account
      if @account.update_attributes(params[:account])
        flash[:success] = "Account #{@account.name} (#{@account.email}) saved"
        params[:save_and_continue] ?
          redirect(url(:accounts, :index)) :
          redirect(url(:accounts, :edit, id: @account.id))
      else
        flash.now[:error] = "Account #{@account.name} (#{@account.email}) could not be saved"
        render 'accounts/edit'
      end
    else
      flash[:warning] = "Account could not be found"
      halt 404
    end
  end

  get :confirm_destroy, with: :id do
    @title = 'Delete Account'
    @account = Account.find(params[:id])

    render 'accounts/confirm_destroy'
  end

  delete :destroy, with: :id do
    redirect_to url(:accounts, :index) unless params[:confirm]

    @title = "Accounts"
    account = Account.find(params[:id])
    if account
      if account != current_account && account.destroy
        flash[:success] = "Account #{account.name} (#{account.email}) deleted"
      else
        flash[:error] = "Account #{account.name} (#{account.email}) could not be deleted"
      end
      redirect url(:accounts, :index)
    else
      flash[:warning] = "Account could not be found"
      halt 404
    end
  end

end
