BoltonCms::Manage.controllers :pages do

  get :index do
    @title = "All Pages"
    @pages = Page.where parent: nil

    render 'pages/index'
  end

  get :new do
    @parent = Page.find params[:parent] if params[:parent]

    @title = 'New Page'
    @page = Page.new

    @page.template = :default
    @page.manage_fragments BoltonCms::TEMPLATES[@page.template.to_s]['fragments'].clone

    render 'pages/new'
  end

  post :create do
    @page = Page.new(params[:page])
    @page.creator = current_account
    @page.manage_fragments BoltonCms::TEMPLATES[@page.template.to_s]['fragments'].clone

    if @page.save
      flash[:success] = "Page '#{@page.title}' created"

      params[:save_and_continue] ?
        redirect(url(:pages, :index)) :
        redirect(url(:pages, :edit, id: @page.id))
    else
      flash.now[:error] = "Page '#{@page.title}' could not be created"

      render 'pages/new'
    end
  end

  get :edit, with: :id do
    @title = 'Edit Page'
    @page = Page.find(params[:id])

    if @page
      render 'pages/edit'
    else
      flash[:warning] = "Page could not be found"

      halt 404
    end
  end

  put :update, with: :id do
    @page = Page.find(params[:id])

    if @page
      @page.updater = current_account

      if params[:new_asset][:file]
        @page.assets << Asset.new(
          gravity: params[:new_asset][:gravity],
          attachment: params[:new_asset][:file]
        )
      end

      if @page.update_attributes(params[:page])
        fragments = BoltonCms::TEMPLATES[@page.template.to_s]['fragments'] || []
        @page.manage_fragments fragments.clone

        flash[:success] = "Page '#{@page.title}' saved"

        params[:save_and_continue] ?
          redirect(url(:pages, :index)) :
          redirect(url(:pages, :edit, id: @page.id))
      else
        flash.now[:error] = "Page '#{@page.title}' could not be saved"

        render 'pages/edit'
      end
    else
      flash[:warning] = "Page could not be found"

      halt 404
    end
  end

  get :confirm_destroy, with: :id do
    @title = 'Delete Page'
    @page = Page.find(params[:id])

    render 'pages/confirm_destroy'
  end

  delete :destroy, with: :id do
    redirect_to url(:pages, :index) unless params[:confirm]

    @title = "Pages"
    page = Page.find(params[:id])

    if page
      page_title = page.title

      if page.destroy
        flash[:success] = "Page '#{page_title}' deleted"
      else
        flash[:error] = "Page '#{page_title}' could not be deleted"
      end

      redirect url(:pages, :index)
    else
      flash[:warning] = "Page could not be found"

      halt 404
    end
  end

end
