module BoltonCms

  class AttachmentUploader < CarrierWave::Uploader::Base

    include CarrierWave::MimeTypes
    include CarrierWave::MiniMagick

    def store_dir
      "#{Padrino.root}/public/#{mounted_as}/#{model.page.id}"
    end
    def cache_dir
      "#{Padrino.root}/public/#{mounted_as}-cache"
    end
    storage :file

    def extension_white_list
      %w(jpg jpeg gif png)
    end
    process :set_content_type

    # Image Size configuration must be overridden
    image_sizes = YAML::load(File.open("#{Padrino.root}/bolton_cms/config/image_sizes.yml")) || {}
    default_size = image_sizes.delete('default')

    process :"dyn_resize_#{default_size['resize']}" => [default_size]

    image_sizes.each do |size, options|
      version size.to_sym do
        process :"dyn_resize_#{options['resize']}" => [options]
      end
    end

    version :manage_thumb do
      process :dyn_resize_fill => [{ "width" => 190, "height" => 100 }]
    end

    def dyn_resize_limit(options)
      resize_to_limit options['width'], options['height']
    end

    def dyn_resize_fit(options)
      resize_to_fit options['width'], options['height']
    end

    def dyn_resize_fill(options)
      resize_to_fill options['width'], options['height'], model.gravity
    end

    def dyn_resize_pad(options)
      resize_and_pad options['width'], options['height'], (options['background'] || :transparent), model.gravity
    end

  end

end
